@@ -2,4 +2,4 @@ from cosmoglobe.sky import model_from_chain
 from cosmoglobe.sky.model import SkyModel
 from cosmoglobe.h5.chain import Chain, copy_chain, combine_chains
 from cosmoglobe.hub import get_test_chain
-from cosmoglobe.plot import plot, gnom, trace
+from cosmoglobe.plot import plot, gnom, trace, hist, spec, standalone_colorbar
